#
# spec file for package openxcom
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           openxcom
Version:        1.0.0.1615230250.adb97235b
Release:        1.17
Summary:        An open source reimplementation of the original X-Com game
License:        GPL-3.0-only
URL:            https://openxcom.org/
Source:         OpenXcom-%{version}.tar.xz
BuildRequires:  cmake
BuildRequires:  dos2unix
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(SDL_gfx)
BuildRequires:  pkgconfig(SDL_image)
BuildRequires:  pkgconfig(SDL_mixer)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(sdl)
BuildRequires:  pkgconfig(yaml-cpp) >= 0.5
Obsoletes:      %{name}-doc

%description
OpenXcom is an open-source clone of the original UFO: Enemy Unknown
(X-Com: UFO Defense in USA), licensed under the GPL and written in C++ / SDL.

The goal of the project is to bring back the tried and true feel of the original
with none of the issues. All the same graphics, sound and gameplay with a brand
new codebase written from scratch.

User is required to have original gamedata (possible to obtain from e.g. Steam)
installed to ~/.local/share/openxcom/data/

%prep
%setup -q -n OpenXcom-%{version}
dos2unix *.txt

%build
%cmake
%cmake_build

%install
%cmake_install
rm %{buildroot}/usr/man/man6/openxcom.6

%files
%license LICENSE.txt
%doc README.md CHANGELOG.txt
%{_datadir}/applications/openxcom.desktop
%{_datadir}/icons/hicolor/*/apps/openxcom.*
%{_datadir}/%{name}/
%{_bindir}/%{name}

%changelog
* Thu Mar 25 2021 tomas.chvatal@gmail.com
- Update to version 1.0.0.1615230250.adb97235b:
  * Fix Elerium crafts potentially wasting one item of fuel during maintenance.
  * Fix Broken Korean Letters
  * Compatibility with OXCE saves
  * More precise distance calculation for 2x2 units
  * More generous detection
  * Don't bother with brew update, it often fails
  * Remove Travis builds
  * fix drag scrolling with black borders, part 2
  * Fix inventory sprite checks
* Fri Nov  6 2020 Tomáš Chvátal <tchvatal@suse.com>
- Switch to cmake build system as upstream deprecates the
  autotools one
* Fri Nov  6 2020 tchvatal@suse.com
- Update to version 1.0.0.1604610320.4639493f0:
  * Stop the charade
  * Stop using in-tree builds and use the ENABLE_WARNING setting instead of rolling our own custom flags.
  * Move CI to ubuntu 20.04 and use the yaml-cpp package
  * silence OpenGL deprecation warnings on MacOS 10.14+
  * Final fix to 25y bug with throw
  * Make shuffle deterministic
  * Add missing Croatian characters
  * Prevent AI frozen in place
  * Fix build with clang 10.0.1 on FreeBSD
  * Hack throw bug
  * Mission zone fix
  * Prevent psionic capture of uncapturable units
  * Unified production monetary cost check
  * Fix research lookup costs
  * Set artifact site counters when loading OG saves
  * fix small bug with melee reaction
  * fix up some HWP damage values
  * fix zombie armour values
  * fix warnings about missing override keyword
  * fix string conversion warnings
  * treat third-party include files as system includes
  * Allow player access to the built-in melee attack for Lobstermen
  * Fixed average monthly rating calculation in StatisticsState
* Thu Jun 25 2020 tchvatal@suse.com
- Update to version 1.0.0.1592170963.8ae998af3:
  * Fix potential leak in window position option
  * Don't load sounds when audio is disabled
  * Typo
  * Make demigod difficulty a mod setting
  * add demigod to new battle mode
  * add 6th difficulty to stats page
  * restore vanilla superhuman difficulty and add demigod level
  * unify crash/destruction checks for UFOs
  * Fix encoding
  * Revert "game loop: reduce idle cpu burn"
* Sat Mar 23 2019 tchvatal@suse.com
- Switch to github service as there was no release since 2014
  and there are simply too many fixes in the git repository
- Update to version 1.0.0.1552426261.8a4b13d65:
  * Update links
  * Check if OXCE is required when enabling mods
  * Don't replenish empty medikits after reload
  * Fix language loading to properly default to en-US when translations are missing. Prioritize untranslated text over incorrect text.
  * Correctly drop units on the ground
  * Fix handling a mix of unconscious and MIA units
  * Fix handling of unconscious ignored units
  * Fix ignored units making it through to the next stage
- Remove upstream patches:
  * openxcom-math.patch
  * openxcom-abs.patch
* Wed Feb 14 2018 tchvatal@suse.com
- Add patch fixing build with gcc7 by explicitly stating math
  includes:
  * openxcom-math.patch
* Fri Jun 17 2016 tchvatal@suse.com
- Add patch fixing gcc6 build bnc#985174:
  * openxcom-abs.patch
* Mon Mar 28 2016 tchvatal@suse.com
- Enable verbose build
- Do not hardcode manpage suffix
* Thu Jul 17 2014 tchvatal@suse.com
- Fix collisions between -doc and regular pkg.
* Tue Jul  8 2014 tchvatal@suse.com
- Install license and other docs.
* Fri Jul  4 2014 tchvatal@suse.com
- Fix Sources url as it aint woring at all.
* Sat Jun 14 2014 mailaender@opensuse.org
- Update to version 1.0.0
* Mon May 20 2013 tchvatal@suse.com
- Version bump to 0.9.0: major update with almost full possible
  gameplay.
* Mon Nov 12 2012 tchvatal@suse.com
- Version bump to 0.4.5. Fix various warnings from obs.
* Sun Oct 28 2012 tchvatal@suse.com
- Bump the version to 0.4.5_pre20121028 as upstream release is
  broken and it is fixed in git.
* Sat Oct 27 2012 tchvatal@suse.com
- Bump the version to 0.4
* Tue Nov 22 2011 tchvatal@suse.com
- Initial commit of openxcom.
